@@ -3,7 +3,7 @@ set -ex
 # sspi-rs doesn't have versions, this just needs to be bumped when new changes
 # are needed.
 # https://github.com/Devolutions/sspi-rs
-DEVOLUTIONS_COMMIT_ID="98e34308377877a6601a07f39da8c329a1e6b08e"
+DEVOLUTIONS_COMMIT_ID="d7b9ff6ffd2157c2f40953c5afc645a7ae203a1e"
 
 # Aligns to a release on https://github.com/unicode-org/icu/tree/main
 ICU_VERSION="73.2"
@@ -64,25 +64,7 @@ make -j${CPUS}
 
 popd
 
-if [ x"${SSPI_BUILD_MACOS_AARCH64:-}" = "xtrue" ]; then
-    mkdir -p "${SSPILIB_PATH}/icu-arm64"
-    pushd "${SSPILIB_PATH}/icu-arm64"
-
-    CFLAGS="${ICU_CFLAGS} -arch arm64" CXXFLAGS="${ICU_CXXFLAGS} ${CFLAGS}" \
-        "${SSPILIB_PATH}/icu/source/configure" \
-        "${ICU_CONFIGURE_FLAGS[@]}" \
-        --disable-tools \
-        --host=arm-apple-darwin \
-        --with-cross-build="${SSPILIB_PATH}/icu-native"
-
-    make -j${CPUS}
-
-    popd
-
-    cp "${SSPILIB_PATH}"/icu-arm64/lib/*.a "${SSPILIB_LIB_PATH}/"
-else
-    cp "${SSPILIB_PATH}"/icu-native/lib/*.a "${SSPILIB_LIB_PATH}/"
-fi
+cp "${SSPILIB_PATH}"/icu-native/lib/*.a "${SSPILIB_LIB_PATH}/"
 
 echo "Copying header files to shared include dir"
 cp -R "${SSPILIB_PATH}"/icu/source/common/* "${CPATH}"
@@ -119,12 +101,6 @@ SSPI_RS_OPTIONS=(
 )
 SSPI_RS_TARGET_DIR="release"
 
-if [ x"${SSPI_BUILD_MACOS_AARCH64:-}" = "xtrue" ]; then
-    rustup target add aarch64-apple-darwin
-    SSPI_RS_OPTIONS+=("--target=aarch64-apple-darwin")
-    SSPI_RS_TARGET_DIR="aarch64-apple-darwin/release"
-fi
-
 echo "Compiling sspi-rs release library"
 cargo build "${SSPI_RS_OPTIONS[@]}"
 
